#!/bin/sh

# Shell script which installs the MaraDNS files in the appropriate directories

# We call install.locations to set BIN, SBIN, MAN1, MAN8, and DOCS
# It is in a separate file to insure that install.sh and uninstall.sh
# have the same values
. ./install.locations

# Make sure that the various install directories actually exist
if [ ! -d "$BIN" ] ; then
	echo The directory $BIN does not exist.  Please edit the file
	echo install.locations by hand.
	exit 2
fi
if [ ! -d "$SBIN" ] ; then
	echo The directory $SBIN does not exist.  Please edit the file
	echo install.locations by hand.
	exit 3
fi
if [ ! -d "$MAN1" ] ; then
	echo The directory $MAN1 does not exist.  Please edit the file
	echo install.locations by hand.
	exit 4
fi
if [ ! -d "$MAN5" ] ; then
	echo The directory $MAN5 does not exist.  Please edit the file
	echo install.locations by hand.
	exit 7
fi
if [ ! -d "$MAN8" ] ; then
	echo The directory $MAN8 does not exist.  Please edit the file
	echo install.locations by hand.
	exit 5
fi

# Make sure we have a place to put documents
if [ ! -d "$DOCS" ] ; then
	if ! mkdir "$DOCS" ; then
		echo unable to make the $DOCS directory. 
		exit 6
	fi
fi

echo Installing MaraDNS, placing programs in $BIN and $SBIN,
echo man pages in $MAN1, $MAN5, 
echo and $MAN8, and documents in $DOCS

# Place the binaries in $BIN and $SBIN
cd server
# We remove the file first to avoid the "text file busy" problem
if [ -e $SBIN/maradns ] ; then
	rm $SBIN/maradns
fi
cp maradns $SBIN
cd ../tuzona
cp getzone $BIN
# We remove the file first to avoid the "text file busy" problem
if [ -e $SBIN/zoneserver ] ; then
	rm $SBIN/zoneserver
fi
cp zoneserver $SBIN
cd ../tools
if [ -e $BIN/askmara ] ; then
	rm $BIN/askmara
fi
cp askmara $BIN
# Place the man pages in $MAN1, $MAN5, and $MAN8
cd ../doc/man
cp askmara.1 getzone.1 $MAN1
cp maradns.8 zoneserver.8 $MAN8
cp csv1.5 mararc.5 $MAN5
# Place all the documents in $DOCS
cd ..
cp -r * $DOCS
# If the system in question does not already have configuration files,
# place example configuration files in /etc
if [ ! -f /etc/mararc ] ; then
	cp example_mararc /etc/mararc
fi
if [ ! -d /etc/maradns ] ; then
	mkdir /etc/maradns
	chmod 755 /etc/maradns
	cp example_csv1 /etc/maradns/db.example.com
fi
# Move some docmentation files in the root of the MaraDNS 
# tree in to the location of installed docs
cd ..
cp 0QuickStart changelog.html maradns.pgp.key $DOCS
